import { Property } from '../../proxy';
import { Expectation, ReturnValue } from '../expectation';
import { CallMap, ExpectationRepository } from './expectation-repository';
export declare type CountableExpectation = {
    expectation: Expectation;
    matchCount: number;
};
export declare abstract class BaseRepository implements ExpectationRepository {
    protected readonly expectations: Map<Property, CountableExpectation[]>;
    private readonly expectedCallStats;
    private readonly unexpectedCallStats;
    add(expectation: Expectation): void;
    clear(): void;
    get(property: Property): ReturnValue;
    getAllProperties(): Property[];
    getCallStats(): {
        expected: CallMap;
        unexpected: CallMap;
    };
    getUnmet(): Expectation[];
    /**
     * We got a method call that doesn't match any expectation,
     * what should we return?
     */
    protected abstract getValueForUnexpectedCall(property: Property, args: any[]): any;
    /**
     * We got a property access that doesn't match any expectation,
     * what should we return?
     */
    protected abstract getValueForUnexpectedAccess(property: Property): ReturnValue;
    protected abstract consumeExpectation(expectation: CountableExpectation): void;
    /**
     * Record an expected property access/method call.
     */
    private recordExpected;
    /**
     * Record an unexpected property access/method call.
     */
    private recordUnexpected;
    private countAndConsume;
}
