import { Matcher } from '../expectation/matcher';
export declare type StrongMockDefaults = {
    /**
     * The matcher that will be used when one isn't specified explicitly.
     *
     * @param expected The non matcher expected value.
     *
     * @example
     * StrongMock.setDefaults({
     *   matcher: () => It.matches(() => true)
     * });
     *
     * when(() => fn('value')).thenReturn(true);
     *
     * fn('not-value') === true;
     */
    matcher: <T>(expected: T) => Matcher;
};
export declare let currentDefaults: StrongMockDefaults;
/**
 * Override strong-mock's defaults.
 *
 * @param newDefaults These will be applied to the library defaults. Multiple
 *   calls don't stack e.g. calling this with `{}` will clear any previously
 *   applied defaults.
 */
export declare const setDefaults: (newDefaults: Partial<StrongMockDefaults>) => void;
