import { ExpectationRepository } from '../expectation/repository/expectation-repository';
import { ExpectationFactory } from '../when/pending-expectation';
export declare type Mock<T> = T;
export declare let isRecording: boolean;
export declare const setRecording: (recording: boolean) => void;
interface MockOptions {
    /**
     * You can provide your own repository to store and find expectations.
     */
    repository?: ExpectationRepository;
    /**
     * You can provide your own way of creating expectations.
     */
    expectationFactory?: ExpectationFactory;
}
/**
 * Create a type safe mock.
 *
 * @see {@link when} Set expectations on the mock using `when`.
 *
 * @example
 * const fn = mock<() => number>();
 *
 * when(() => fn()).thenReturn(23);
 *
 * fn() === 23;
 */
export declare const mock: <T>({ repository, expectationFactory, }?: MockOptions) => T;
export {};
